<?php
/*
	Plugin Name: Contact Form 7 googlesheet extesion.
	Plugin URI: https://pardeepnadha.wordpress.com/
	Description: Upload data to Google Sheets using Contact Form 7.
	Text Domain: cf7-pk-googlesheets
	Author: Pardeep Nadha
	Version: 1.0
	Author URI: https://pardeepnadha.wordpress.com/
	License: 
*/


if ( ! defined( 'ABSPATH' ) ) {
	exit; // exit if accessed directly!
}

require_once plugin_dir_path(__FILE__).'php-google-oauth/Google_Client.php';


class CF7_pk_googlesheets_extension {
 
    public function __construct() {
 
        load_plugin_textdomain( 'cf7-pk-googlesheets', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' );
		
		// Admin notices
		add_action( 'admin_notices', array($this,'admin_notices'), 11 );
		
		// Add Config page as a sub menu item on the Admin page in contact form 7
		add_action( 'admin_menu', array($this,'cf7_pk_googlesheets_admin_menu'));
		
		// contact form 7 hook work after mail sent
		add_action( 'wpcf7_mail_sent', array($this, 'cf7_pk_googlesheets_savedata_to_googlesheet'), 1);
    }
	
	/**
     * show notices if contact form is not activated
     */
	 
	function admin_notices() {
		// check exist cf7 class
		if ( !function_exists( 'wpcf7' ) ) {
			$class = 'notice notice-error';
			$message = __( 'Please install Contact Form 7 Plugin before activate this plugin', 'sample-text-domain' );
			printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message ); 
			deactivate_plugins ( 'contact-form-7-pk-googlesheet-extension/contact-form-7-pk-googlesheet-extension.php' );
		}
	}
	
	/**
     * Add submenu page for this plugin in WP Admin
     * @return void
     */
	
	function cf7_pk_googlesheets_admin_menu(){
        add_submenu_page('wpcf7',
		 'Contact Form to Google Extension',
		 __('GoogleSheet Integration', 'contact-form-7-to-google-extension'),
		 'manage_options',
		 'googlesheet',
		 array(&$this, 'cf7_pk_googlesheets_admin_integration_settingpage'));
	}
	
	/**
	 * callback function for submenu page show setting form
	 */
	function cf7_pk_googlesheets_admin_integration_settingpage(){ ?>
		<div id="theme-options-wrap">
		<div class="icon32" id="icon-tools"> <br /> </div>
		<h2>Google Sheet Integration Settings</h2>
		<p>Update various settings from google console to this form.</p>
		<?php
				if(isset($_POST['savefield'])){
					foreach($_POST as $key=>$value){
					//print_r($_POST);
					update_option( $key, $value );
					}
				}
				if(isset($_FILES['cf7_pk_googlesheets_keyfile']['name'])){
				$uploaddir =  plugin_dir_path(__FILE__) .'/';
				$uploadfile = $uploaddir . basename($_FILES['cf7_pk_googlesheets_keyfile']['name']);
				$filename =  $_FILES['cf7_pk_googlesheets_keyfile']['name'];
			
				if (move_uploaded_file($_FILES['cf7_pk_googlesheets_keyfile']['tmp_name'], $uploadfile)) {
					  update_option( 'cf7_pk_googlesheets_keyfile', $filename );
					}
				}
				
		?>
		<form method="post" action="" enctype="multipart/form-data">
			
			<input type='hidden' name='_wpnonce' value='<?php echo wp_create_nonce('cf7_pk_goglesheet'); ?>' />
			<table class="form-table">
			<tbody>
			<tr>
				<th scope="row">Contact Form 7 ID to use</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_formid');?>" name="cf7_pk_googlesheets_formid"><br></td>
			</tr>
			<tr>
				<th scope="row">Google Client App Name</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_appname');?>" name="cf7_pk_googlesheets_appname">
				<br><span></span></td>
			</tr>
			<tr>
				<th scope="row">Google Client ID</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_clientid');?>" name="cf7_pk_googlesheets_clientid"><br></td>
			</tr>
			<tr>
				<th scope="row">Google Client Email</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_clientemail');?>" name="cf7_pk_googlesheets_clientemail"><br></td>
			</tr>
			<tr>
				<th scope="row">Google Sheet Name</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_sheetname');?>" name="cf7_pk_googlesheets_sheetname"><br></td>
			</tr>
			<tr>
				<th scope="row">Google Sheet Tab Name</th>
				<td><input type="text" value="<?php echo get_option('cf7_pk_googlesheets_tabname');?>" name="cf7_pk_googlesheets_tabname"><br></td>
			</tr>
			<tr>
				<th scope="row">Upload Client Key File(example:-My_Project-c6a534e11e68.p12)</th>
				<td><input type="file" name="cf7_pk_googlesheets_keyfile"><br>
				<span>Uploaded file:-  <?php echo get_option('cf7_pk_googlesheets_keyfile');?></apan></td>
			</tr>
			</tbody></table>
			<p class="submit">
				<input name="savefield" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" />
			</p>
		</form>
	</div>
	<?php }
	
	
	function cf7_pk_googlesheets_savedata_to_googlesheet($cf7) {

		// Use WPCF7_Submission object's 
        $submission = WPCF7_Submission::get_instance();
		
        if ($submission) {
			// get post data from contact form 7
			$savedata = array();
            $posted_data = $submission->get_posted_data();
			// match cf7 id here
				if ( $posted_data['_wpcf7'] == get_option('cf7_pk_googlesheets_formid') ) {
					
					foreach ( $posted_data as $key => $value ) {
						if ( strpos($key, '_wpcf7') !== false || strpos($key, '_wpnonce') !== false ) {
							
						} else {
								$savedata[$key] = $value;
							}					
					}
					
					$CLIENT_APP_NAME = get_option('cf7_pk_googlesheets_appname');
					$CLIENT_ID       = get_option('cf7_pk_googlesheets_clientid');
					$CLIENT_EMAIL    = get_option('cf7_pk_googlesheets_clientemail');
					$CLIENT_KEY_PATH = plugin_dir_path(__FILE__).get_option('cf7_pk_googlesheets_keyfile'); // PATH_TO_KEY = where you keep your key file
					$CLIENT_KEY_PW   = 'notasecret';
					 
					$objClientAuth  = new Google_Client ();
					$objClientAuth -> setApplicationName ($CLIENT_APP_NAME);
					$objClientAuth -> setClientId ($CLIENT_ID);
					$objClientAuth -> setAssertionCredentials (new Google_AssertionCredentials (
						$CLIENT_EMAIL, 
						array('https://spreadsheets.google.com/feeds','https://docs.google.com/feeds'), 
						file_get_contents ($CLIENT_KEY_PATH), 
						$CLIENT_KEY_PW
					));
					$objClientAuth->getAuth()->refreshTokenWithAssertion();
					$objToken  = json_decode($objClientAuth->getAccessToken());
					$accessToken = $objToken->access_token;
					
					include_once(plugin_dir_path(__FILE__) . "connect_google.php");
					$connectgoogle = new connect_google();
					$addrow = $connectgoogle->add_row($accessToken,$savedata);
					
				}
        }
	}
	
}

new CF7_pk_googlesheets_extension();
